@@ -14,14 +14,6 @@ mod tests {
         assert!(gjk.intersect(&a, &b).is_none());
         assert!(gjk.intersect(&a, &c).is_some());
         assert!(gjk.intersect(&b, &c).is_some());
-
-        let c = Circle::new(Vector2::new(4.6, -3.2), 1.43);
-        let r = AABB::new(Vector2::new(-1.0, 0.5), Vector2::new(2.0, 1.0));
-        let p = Polygon::new(Vector2::new(0.0, 0.0),
-                             vec![Vector2::new(0.0, 0.5),
-                                  Vector2::new(-1.5, -0.5),
-                                  Vector2::new(-3.0, 0.5),
-                             ]);
     }
 
     #[test]
@@ -70,4 +62,16 @@ mod tests {
         assert!(gjk.intersect(&c_a, &r_a).is_some());
         assert!(gjk.intersect(&c_b, &r_a).is_none());
     }
+
+    #[test]
+    fn continuous () {
+        let gjk = GJK::new();
+
+        let c_a = Circle::new(Vector2::new(0.0, 0.0), 1.0);
+        let c_b = Circle::new(Vector2::new(0.0, -3.0), 1.0);
+
+        let r = gjk.intersection_time_of_impact(&c_a, Vector2::ZERO, &c_b, Vector2::new(0.0, 4.0));
+
+        assert_eq!(r.unwrap().time_of_impact, 1.0 / 4.0);
+    }
 }
\ No newline at end of file
